@@ -100,7 +100,7 @@ def xml_to_dict(xml_filepath: Path, section_start: str = None, section_end: str
 class FewsConfig:
 
     geo_datum = {"Rijks Driehoekstelsel": "epsg:28992"}
-    Z_NODATA_VALUE = -9999
+    Z_NODATA_VALUE = -9999.0
 
     def __init__(self, path: Path):
         self.path = path
@@ -209,16 +209,18 @@ class FewsConfig:
     def add_geometry_column(
         cls, gdf: gpd.GeoDataFrame, filepath: Path, x_attrib: str, y_attrib: str, z_attrib: str = None,
     ) -> gpd.GeoDataFrame:
-        """Add geometry column to geodataframe by merging geodataframe columns x, y, and z.
-        If column z_attrib exists, then we fill empty cells ('') with z_value_default.
-        If column z_attrib does not exists? then we use z_value_default -9999 for all rows.
+        """Add geometry column to geodataframe by merging geodataframe columns x, y, and z:
+            - if column z_attrib exists, then we fill empty cells ('') with Z_NODATA_VALUE.
+            - if column z_attrib does not exists? then we use Z_NODATA_VALUE -9999 for all rows.
         """
 
         assert (x_attrib and y_attrib) in gdf.columns, f"x={x_attrib} and y={y_attrib} must be in df"
         if z_attrib:
-            empty_rows_z = len(gdf[gdf[z_attrib] == ""])
-            gdf[z_attrib].replace("", cls.Z_NODATA_VALUE, inplace=True)
-            logger.debug(f"replaced {empty_rows_z} gdf rows column {z_attrib} from '' to {cls.Z_NODATA_VALUE}")
+            assert gdf[z_attrib].dtype == "O"
+            new_value = str(cls.Z_NODATA_VALUE)
+            nr_empty_rows_z = len(gdf[gdf[z_attrib] == ""])
+            gdf[z_attrib].replace("", new_value, inplace=True)
+            logger.debug(f"replaced {nr_empty_rows_z} gdf rows column {z_attrib} from '' to {new_value}")
         try:
             if z_attrib:
                 gdf["geometry"] = gdf.apply(
