@@ -1,10 +1,11 @@
-from hdsr_wis_config_reader.constants import location_sets
 from hdsr_wis_config_reader.constants import paths
-from hdsr_wis_config_reader.tests.fixtures import fews_config
+from hdsr_wis_config_reader.tests.fixtures import loc_sets
+
+import pandas as pd  # noqa pandas comes with geopandas
 
 
 # silence flake8
-fews_config = fews_config
+loc_sets = loc_sets
 
 
 expected_idmap_section_name = "KUNSTWERKEN"
@@ -548,14 +549,16 @@ expected_attrib_files_1_and_2 = [
 ]
 
 
-def test_sublocationset(fews_config):
-    subloc = location_sets.sub.SubLocationSet(fews_config=fews_config)
-    assert subloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
-    assert subloc.idmap_section_name == expected_idmap_section_name
-    assert subloc.name == expected_name
-    assert subloc.csv_filename == expected_csvfile
-    assert subloc.fews_name == expected_fews_name
-    assert subloc.get_validation_attributes(int_pars=None) == expected_validation_attributes
-    assert subloc.validation_rules == expected_validation_rules_1_and_2
-    assert subloc.csv_file_meta == expected_csvfile_meta_1_and_2
-    assert subloc.attrib_files == expected_attrib_files_1_and_2
+def test_sublocationset(loc_sets):
+    assert loc_sets.subloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
+    assert loc_sets.subloc.idmap_section_name == expected_idmap_section_name
+    assert loc_sets.subloc.name == expected_name
+    assert loc_sets.subloc.csv_filename == expected_csvfile
+    assert loc_sets.subloc.fews_name == expected_fews_name
+    assert loc_sets.subloc.get_validation_attributes(int_pars=None) == expected_validation_attributes
+    assert loc_sets.subloc.validation_rules == expected_validation_rules_1_and_2
+    assert loc_sets.subloc.csv_file_meta == expected_csvfile_meta_1_and_2
+    assert loc_sets.subloc.attrib_files == expected_attrib_files_1_and_2
+    assert isinstance(loc_sets.subloc.geo_df, pd.DataFrame)
+    assert isinstance(loc_sets.subloc.geo_df_original, pd.DataFrame)
+    pd.testing.assert_frame_equal(left=loc_sets.subloc.geo_df, right=loc_sets.subloc.geo_df_original)
