@@ -1,13 +1,11 @@
-from hdsr_wis_config_reader.constants import location_sets
-from hdsr_wis_config_reader.tests.fixtures import fews_config
-from hdsr_wis_config_reader.tests.fixtures import locsets
+from hdsr_wis_config_reader.constants.location_sets.base import LocationSetBase
+from hdsr_wis_config_reader.tests.fixtures import loc_sets
 from typing import Dict
 from typing import List
 
 
 # silence flake8
-fews_config = fews_config
-locsets = locsets
+loc_sets = loc_sets
 
 
 general_location_set_dict = [
@@ -1978,39 +1976,59 @@ general_location_set_dict = [
 ]
 
 
-def test_general_location_set_dict(locsets):
-    for locset in locsets:
-        assert locset.general_location_sets_dict == general_location_set_dict
+def test_general_location_set_dict(loc_sets):
+    assert loc_sets.hoofdloc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.subloc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.waterstandloc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.psloc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.mswloc.general_location_sets_dict == general_location_set_dict
 
 
-def _attribs(locset: location_sets.base.LocationSetBase):
-    return locset.get_validation_attributes(int_pars=None)
+def test_unique_validation_attributes(loc_sets):
+    def _attribs(loc_set: LocationSetBase):
+        return loc_set.get_validation_attributes(int_pars=None)
+
+    assert _attribs(loc_sets.hoofdloc) and _attribs(loc_sets.subloc) and _attribs(loc_sets.waterstandloc)
+    assert _attribs(loc_sets.mswloc) == [] and _attribs(loc_sets.psloc) == []
+    assert _attribs(loc_sets.hoofdloc) != _attribs(loc_sets.subloc) != _attribs(loc_sets.mswloc)
 
 
-def _meta(locset: location_sets.base.LocationSetBase, general_location_set_dict: List[Dict]):
-    return [loc_set for loc_set in general_location_set_dict if loc_set["id"] == locset.fews_name][0]["csvFile"]
+def test_unique_csvfile_meta(loc_sets):
+    def _meta(_loc_set: LocationSetBase, general_location_set_dict: List[Dict]):
+        return [loc_set for loc_set in general_location_set_dict if loc_set["id"] == _loc_set.fews_name][0]["csvFile"]
+
+    assert (
+        loc_sets.hoofdloc.csv_file_meta
+        and loc_sets.subloc.csv_file_meta  # noqa
+        and loc_sets.waterstandloc.csv_file_meta  # noqa
+        and loc_sets.mswloc.csv_file_meta  # noqa
+        and loc_sets.psloc.csv_file_meta  # noqa
+    )
+    assert (
+        loc_sets.hoofdloc.csv_file_meta  # noqa
+        != loc_sets.subloc.csv_file_meta  # noqa
+        != loc_sets.waterstandloc.csv_file_meta  # noqa
+        != loc_sets.mswloc.csv_file_meta  # noqa
+        != loc_sets.psloc.csv_file_meta  # noqa
+    )
+    assert loc_sets.hoofdloc.csv_file_meta == _meta(
+        _loc_set=loc_sets.hoofdloc, general_location_set_dict=general_location_set_dict
+    )
+    assert loc_sets.subloc.csv_file_meta == _meta(
+        _loc_set=loc_sets.subloc, general_location_set_dict=general_location_set_dict
+    )
+    assert loc_sets.waterstandloc.csv_file_meta == _meta(
+        _loc_set=loc_sets.waterstandloc, general_location_set_dict=general_location_set_dict
+    )
+    assert loc_sets.psloc.csv_file_meta == _meta(
+        _loc_set=loc_sets.psloc, general_location_set_dict=general_location_set_dict
+    )
+    assert loc_sets.mswloc.csv_file_meta == _meta(
+        _loc_set=loc_sets.mswloc, general_location_set_dict=general_location_set_dict
+    )
 
 
-def test_unique_validation_attributes(locsets):
-    hoofdloc, subloc, wsloc, mswloc, psloc = locsets
-    assert _attribs(hoofdloc) and _attribs(subloc) and _attribs(wsloc)
-    assert _attribs(mswloc) == [] and _attribs(psloc) == []
-    assert _attribs(hoofdloc) != _attribs(subloc) != _attribs(mswloc)
-
-
-def test_unique_csvfile_meta(locsets):
-    hoofd, sub, ws, msw, ps = locsets
-    assert hoofd.csv_file_meta and sub.csv_file_meta and ws.csv_file_meta and msw.csv_file_meta and ps.csv_file_meta
-    assert hoofd.csv_file_meta != sub.csv_file_meta != ws.csv_file_meta != msw.csv_file_meta != ps.csv_file_meta
-    assert hoofd.csv_file_meta == _meta(locset=hoofd, general_location_set_dict=general_location_set_dict)
-    assert sub.csv_file_meta == _meta(locset=sub, general_location_set_dict=general_location_set_dict)
-    assert ws.csv_file_meta == _meta(locset=ws, general_location_set_dict=general_location_set_dict)
-    assert ps.csv_file_meta == _meta(locset=ps, general_location_set_dict=general_location_set_dict)
-    assert msw.csv_file_meta == _meta(locset=msw, general_location_set_dict=general_location_set_dict)
-
-
-def test_unique_attribute_files(locsets):
-    hoofd, sub, ws, msw, ps = locsets
-    assert hoofd.attrib_files and sub.attrib_files and ws.attrib_files
-    assert msw.attrib_files == [] and ps.attrib_files == []
-    assert hoofd.attrib_files != sub.attrib_files != ws.attrib_files
+def test_unique_attribute_files(loc_sets):
+    assert loc_sets.hoofdloc.attrib_files and loc_sets.subloc.attrib_files and loc_sets.waterstandloc.attrib_files
+    assert loc_sets.mswloc.attrib_files == [] and loc_sets.psloc.attrib_files == []
+    assert loc_sets.hoofdloc.attrib_files != loc_sets.subloc.attrib_files != loc_sets.waterstandloc.attrib_files
