@@ -1,10 +1,11 @@
-from hdsr_wis_config_reader.constants import location_sets
 from hdsr_wis_config_reader.constants import paths
-from hdsr_wis_config_reader.tests.fixtures import fews_config
+from hdsr_wis_config_reader.tests.fixtures import loc_sets
+
+import pandas as pd  # noqa pandas comes with geopandas
 
 
 # silence flake8
-fews_config = fews_config
+loc_sets = loc_sets
 
 expected_idmap_section_name = "WATERSTANDLOCATIES"
 expected_name = "waterstandlocaties"
@@ -334,14 +335,18 @@ expected_attrib_files = [
 ]
 
 
-def test_waterstandlocationset_2(fews_config):
-    wsloc = location_sets.ow.WaterstandLocationSet(fews_config=fews_config)
-    assert wsloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
-    assert wsloc.idmap_section_name == expected_idmap_section_name
-    assert wsloc.name == expected_name
-    assert wsloc.csv_filename == expected_csvfile
-    assert wsloc.fews_name == expected_fews_name
-    assert wsloc.get_validation_attributes(int_pars=None) == expected_validation_attributes
-    assert wsloc.validation_rules == expected_validation_rules
-    assert wsloc.csv_file_meta == expected_csvfile_meta
-    assert wsloc.attrib_files == expected_attrib_files
+def test_waterstandlocationset(loc_sets):
+    assert loc_sets.waterstandloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
+    assert loc_sets.waterstandloc.idmap_section_name == expected_idmap_section_name
+    assert loc_sets.waterstandloc.name == expected_name
+    assert loc_sets.waterstandloc.csv_filename == expected_csvfile
+    assert loc_sets.waterstandloc.fews_name == expected_fews_name
+    assert loc_sets.waterstandloc.get_validation_attributes(int_pars=None) == expected_validation_attributes
+    assert loc_sets.waterstandloc.validation_rules == expected_validation_rules
+    assert loc_sets.waterstandloc.csv_file_meta == expected_csvfile_meta
+    assert loc_sets.waterstandloc.attrib_files == expected_attrib_files
+    assert isinstance(loc_sets.waterstandloc.geo_df, pd.DataFrame)
+    assert isinstance(loc_sets.waterstandloc.geo_df_original, pd.DataFrame)
+    pd.testing.assert_frame_equal(left=loc_sets.waterstandloc.geo_df, right=loc_sets.waterstandloc.geo_df_original)
+    assert "Z" in loc_sets.waterstandloc.geo_df
+    assert not loc_sets.waterstandloc.geo_df["Z"].hasnans
