@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.constants.idmappings.collection import IdMappingCollection
+from hdsr_wis_config_reader import IdMappingCollection
 from hdsr_wis_config_reader.tests.fixtures import fews_config
 from hdsr_wis_config_reader.utils import is_equal_dataframes
 
